﻿using ConsoleHotKey;
using System;
using System.Data;
using System.Media;
using System.Windows.Forms;

namespace WindowsFormsApplication1
{
    public partial class Main : Form
    {
        private delegate void updateStatsCallback();
        private delegate void rPressedCallback(int m);
        private delegate void SetTextCallback(string text);

        private Document wDoc;
        private static Main fmain;

        public Main()
        {
            fmain = this;
            InitializeComponent();

            HotKeyManager.RegisterHotKey(Keys.F10, KeyModifiers.NoRepeat);
            HotKeyManager.RegisterHotKey(Keys.F11, KeyModifiers.NoRepeat);

            HotKeyManager.HotKeyPressed += new EventHandler<HotKeyEventArgs>(HotKeyManager_HotKeyPressed);

            //HotKeyManager.UnregisterHotKey(_hkNext);
            //HotKeyManager.UnregisterHotKey(_hkRetry);
            //_hkNext = 0;
            //_hkRetry = 0;

        }


        private void Init()
        {

            wDoc = new Document(this);
            dGV.DataSource = wDoc.GetDS();
            dGV.AutoGenerateColumns = false;
            dGV.Columns[0].AutoSizeMode = DataGridViewAutoSizeColumnMode.AllCells;
            dGV.Columns[1].AutoSizeMode = DataGridViewAutoSizeColumnMode.AllCells;
            //   dGV.Columns[1].ReadOnly = true;

            dGV.Columns[2].AutoSizeMode = DataGridViewAutoSizeColumnMode.ColumnHeader;
            // dGV.Columns[2].CellType = DataGridViewButtonCell;
            dGV.Columns[2].Visible = false;
            dGV.Columns[2].ReadOnly = true;
            dGV.Columns[3].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
            dGV.Columns[4].AutoSizeMode = DataGridViewAutoSizeColumnMode.ColumnHeader;
            dGV.Columns[5].Visible = false;

            dGV.Columns[6].AutoSizeMode = DataGridViewAutoSizeColumnMode.ColumnHeader;
            dGV.Columns[6].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;

            dGV.Columns[7].AutoSizeMode = DataGridViewAutoSizeColumnMode.ColumnHeader;
            dGV.Columns[7].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
            UpdateStats();
            uuedLausedToolStripMenuItem.Enabled = true;
            laused2ToolStripMenuItem.Enabled = true;
            laused3ToolStripMenuItem.Enabled = true;
            laused4ToolStripMenuItem.Enabled = true;
            laeToolStripMenuItem.Enabled = true;
        }

        internal void LoadWork(string fullPath)
        {
            Init();
            wDoc.SetWF(fullPath + "\\");
            wDoc.LoadWork();
            UpdateStats();
        }

        internal void NewWork(string fullPath)
        {
            Init();
            wDoc.SetWF(fullPath + "\\");
            UpdateStats();
        }

        public void UpdateStats()
        {
            if (llWD.InvokeRequired)
            {
                updateStatsCallback d = new updateStatsCallback(UpdateStats);
                Invoke(d, new object[] { });
                return;
            }

            llWD.Text = "Tööjärg:" + wDoc.GetWorkDone() + "/" + wDoc.GetWorkSize();

            if (wDoc.GetWorkSize() > wDoc.GetWorkDone())
            {
                ssButton.Enabled = true;
            }
            else
            {
                ssButton.Enabled = false;
            }
            if (wDoc.IsGCinit())
            {
                ssButton.Text = "Peata töö";
            }
            else
            {
                ssButton.Text = "Alusta tööga";
            }

            wDoc.SaveWork();

        }

        internal void SaveZip(string workPath, string thename)
        {
            SaveFileDialog fd = new SaveFileDialog
            {
                FileName = thename + "",
                Filter = "Eksporidi zip|*.zip",
                Title = "Ekspordi ZIP"
            };
            fd.ShowDialog();

            if (fd.FileName != "")
            {
                Init();
                wDoc.SetWF(workPath + "\\");
                wDoc.LoadWork();
                wDoc.SaveZip(fd.FileName, thename);

            }

        }

        private void Button1_Click(object sender, EventArgs e)
        {
            wDoc.GcNext();
        }



        private bool FolderOK()
        {
            try
            {
                System.Security.AccessControl.DirectorySecurity ds = System.IO.Directory.GetAccessControl(wDoc.GetWF());
                return true;
            }
            catch (Exception ex)
            {
                if (ex is UnauthorizedAccessException || ex is InvalidOperationException || ex is ArgumentException)
                {
                    return false;
                }
                throw;
            }

        }

        private void SsButton_Click(object sender, EventArgs e)
        {
            Console.WriteLine("ssButton_Click");
            if (!wDoc.IsGCinit())
            {
                if (FolderOK())
                {
                    wDoc.GcInit();
                }
                else
                {
                    MessageBox.Show("Vali Töö kaust.", "VALI...", MessageBoxButtons.OK);
                }
            }
            else
            {
                wDoc.GcClose();
            }
            UpdateStats();
        }

        private void UusToolStripMenuItem_Click(object sender, EventArgs e)
        {


        }

        private void LaeToolStripMenuItem_Click(object sender, EventArgs e)
        {

            OpenFileDialog fd = new OpenFileDialog
            {
                Filter = "TXT Import|*.txt",
                Title = "Lae Teksti fail"
            };

            if (fd.ShowDialog() == DialogResult.OK)
            {
                System.IO.StreamReader sr = new System.IO.StreamReader(fd.FileName);
                wDoc.LoadTXT(sr);
            }
            UpdateStats();
        }

        private void SalvestaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog fd = new SaveFileDialog
            {
                Filter = "Tööfail|*.kj1",
                Title = "Salvesta töö"
            };
            fd.ShowDialog();

            if (fd.FileName != "")
            {
                System.IO.FileStream fs =
                     (System.IO.FileStream)fd.OpenFile();

                // NOTE that the FilterIndex property is one-based.
                switch (fd.FilterIndex)
                {
                    case 1:
                        wDoc.Save(fs);
                        break;

                }

                fs.Close();
            }
            UpdateStats();
        }

        private void Button3_Click(object sender, EventArgs e)
        {
            wDoc.GcPause();

        }


        private void DemosetToolStripMenuItem_Click(object sender, EventArgs e)
        {

            wDoc.LoadDemoset();
            UpdateStats();
        }


        public void RPressed(int m)
        {
            rPressedCallback d = new rPressedCallback(RPressedi);
            Invoke(d, new object[] { m });

        }

        private void RPressedi(int m)
        {
            if (m == 1)
            {
                wDoc.GcNext();
            }

            if (m == 2)
            {
                wDoc.GcPause();
            }

        }

        private static void HotKeyManager_HotKeyPressed(object sender, HotKeyEventArgs hotKey)
        {

            if (hotKey.Key == Keys.F10)
            {
                Console.WriteLine("OnHotKeyHandler NEXT");
                fmain.RPressed(1);
            }


            if (hotKey.Key == Keys.F11)
            {
                Console.WriteLine("OnHotKeyHandler Pause");
                fmain.RPressed(2);
            }
        }

        public void SetUtt(string utt)
        {

            if (uUttText.InvokeRequired)
            {
                SetTextCallback d = new SetTextCallback(SetUtt);
                Invoke(d, new object[] { utt });
            }
            else
            {
                uUttText.Text = utt;
            }

        }

        private void Button4_Click(object sender, EventArgs e)
        {
            wDoc.InitCount();
            UpdateStats();
        }

        private void Scroll_button_Click(object sender, EventArgs e)
        {
            int a = wDoc.GetNextWork() - 4;
            if (a < 0)
            {
                a = 0;
            }
            dGV.FirstDisplayedScrollingRowIndex = a;
        }

        private void DGV_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {

            //MessageBox.Show("R:" + e.RowIndex + " C:" + e.ColumnIndex, "CellMouseClick Event");

            //if (e.ColumnIndex == 2 && e.RowIndex > -1){
            //        DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
            //        wDoc.setRowStatus(row);}

            if (dGV.Rows.Count <= 1)
            {
                return;
            }
            if (e.ColumnIndex == 1 && e.RowIndex > -1)
            {
                DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
                wDoc.DoggleRowSkip(row);
            }
            if (e.ColumnIndex == 6 && e.RowIndex > -1)
            {
                DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
                if (!string.Equals((string)row[1], "Ära loe", StringComparison.Ordinal) & !string.Equals((string)row[1], "", StringComparison.Ordinal))
                {
                    SoundPlayer my_wave_file = new SoundPlayer(wDoc.GetFilenameRow(row));
                    my_wave_file.Play();
                }
            }
            if (e.ColumnIndex == 7 && e.RowIndex > -1)
            {
                DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
                wDoc.ClearRowDoneBttn(row);
                UpdateStats();
            }

        }

        private void DGV_CellContentDClick(object sender, DataGridViewCellEventArgs e)
        {

            //MessageBox.Show("R:" + e.RowIndex + " C:" + e.ColumnIndex, "CellMouseClick Event");
            if (e.ColumnIndex == 1)
            {
                if (e.RowIndex > -1)
                {
                    DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
                    wDoc.ClearRowDone(row);
                }
            }
        }


        private void Main_FormClosing(object sender, FormClosingEventArgs e)
        {
            UpdateStats();
            if (wDoc.IsGCinit())
            {
                wDoc.GcClose();
            }
        }

        private void TööToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work);
            UpdateStats();
        }

        private void UuedLausedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work21);
            UpdateStats();
        }

        private void Laused2ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work22);
            UpdateStats();
        }

        private void Laused3ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work23);
            UpdateStats();
        }

        private void Laused4ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work24);
            UpdateStats();
        }

        private void ProovitööToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ((ToolStripMenuItem)sender).Enabled = false;
            wDoc.LoadInternalWork(Laused.work_proov);
            UpdateStats();
        }

        private void Main_KeyDown(object sender, KeyEventArgs e)
        {
            if (Keys.F1 == e.KeyData)
            {
                Main_toggle_visible();
            }
        }
        private void Main_toggle_visible()
        {
            if (button2.Visible)
            {
                button2.Visible = false;
                panel2.Visible = false;
            }
            else
            {
                button2.Visible = true;
                panel2.Visible = true;
            }
        }

        private void Button_close_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void Button4_Click_1(object sender, EventArgs e)
        {
            Help h = new Help();
            h.ShowDialog();
        }
    }
}
