﻿using System;
using System.Data;
using System.IO;
//using System.Windows;
using System.Windows.Forms;

namespace WindowsFormsApplication1
{
    public partial class ProjectForm : Form
    {
        private string rootPath = "";
        private DataTable db = null;
        private readonly Main mainWindow;

        public ProjectForm()
        {
            InitializeComponent();
            mainWindow = new Main();
            InitDB();
            ReadProjects();
            InitDBView();

        }
        private void InitDB()
        {
            db = new DataTable();
            db.Columns.Add("Nimi", typeof(string));
            db.Columns[0].ReadOnly = true;
            db.Columns.Add("Path", typeof(string));
            db.Columns[1].ReadOnly = true;

        }
        private void ReadProjects()
        {
            string path = Environment.GetFolderPath(Environment.SpecialFolder.MyDocuments);
            rootPath = Path.Combine(path, "salvestaja");
            DirectoryInfo directoryInfo = Directory.CreateDirectory(rootPath);
            foreach (DirectoryInfo file in directoryInfo.GetDirectories())
            {
                string fullName = file.FullName;
                string fileName = file.Name;
                string projectPath = Path.Combine(fullName, "0index.kj2");
                if (File.Exists(projectPath))
                {
                    db.Rows.Add(fileName, fullName);
                }
            }
        }
        private void InitDBView()
        {
            dGV.DataSource = db;
            dGV.AutoGenerateColumns = false;
            dGV.Columns[0].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
            dGV.Columns[1].Visible = false;
        }

        private void LoadWork(string fullPath)
        {
            Hide();
            mainWindow.LoadWork(fullPath);
            mainWindow.ShowDialog();
            Show();
        }

        private void ProjectForm_Load(object sender, EventArgs e)
        {

        }

        private void Button_new_Click(object sender, EventArgs e)
        {
            ProjectFormNew askname = new ProjectFormNew();
            if (askname.ShowDialog() == DialogResult.OK)
            {

                Hide();
                string path = Path.Combine(rootPath, askname.WorkName);
                Directory.CreateDirectory(path);
                mainWindow.NewWork(path);
                mainWindow.ShowDialog();
                InitDB();
                ReadProjects();
                InitDBView();
                Show();
            }

        }

        private void DGV_CellContentDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            //MessageBox.Show("R:" + e.RowIndex, "CellMouseClick Event");
            if (e.RowIndex > -1)
            {
                DataRow row = (dGV.Rows[e.RowIndex].DataBoundItem as DataRowView).Row;
                LoadWork((string)row[1]);
            }
        }

        private void Button_open_Click(object sender, EventArgs e)
        {
            //MessageBox.Show("R:" + dGV.SelectedRows.Count, "CellMouseClick Event");
            if (dGV.SelectedRows.Count > 0)
            {
                DataRow row = (dGV.SelectedRows[0].DataBoundItem as DataRowView).Row;
                LoadWork((string)row[1]);
            }
        }

        private void Button_pack_Click(object sender, EventArgs e)
        {
            //MessageBox.Show("R:" + dGV.SelectedRows.Count, "CellMouseClick Event");
            if (dGV.SelectedRows.Count > 0)
            {
                DataRow row = (dGV.SelectedRows[0].DataBoundItem as DataRowView).Row;


                mainWindow.SaveZip((string)row[1], (string)row[0]);

            }
        }

        private void Button_delete_Click(object sender, EventArgs e)
        {
            if (dGV.SelectedRows.Count > 0)
            {
                DataRow row = (dGV.SelectedRows[0].DataBoundItem as DataRowView).Row;
                DialogResult messageBoxResult = MessageBox.Show("Kas kustutame salvestuse '" + (string)row[0] + "'?", "Kustuta", buttons: MessageBoxButtons.YesNo);
                if (messageBoxResult == DialogResult.Yes)
                {
                    //mainWindow.SaveZip((string)row[1]);
                    DirectoryInfo directoryInfo = new DirectoryInfo((string)row[1]);
                    try
                    {
                        directoryInfo.Delete(true);

                    }
                    catch
                    {

                    }
                    row.Delete();

                }



            }
        }

        private void Button_help_Click(object sender, EventArgs e)
        {
            Help h = new Help();
            h.ShowDialog();
        }
    }
}
