﻿using NAudio.Wave;
using System;
using System.IO;
using System.Windows;

namespace WindowsFormsApplication1
{
    internal class Recorder
    {
        private readonly int sampleRate = 22000;
        private readonly int nBits = 16;
        private readonly int channels = 2;
        private bool isRec = false;

        private WaveIn waveIn;
        private WaveFileWriter writer;

        //public Recorder(int sampleRate = 22000, int nBits = 16, int channels = 2)
        //public Recorder(int sampleRate = 192000, int nBits = 32, int channels = 2)
        public Recorder(int sampleRate = 48000, int nBits = 16, int channels = 1)
        {
            this.sampleRate = Properties.Settings.Default.raudSampleRate;
            this.sampleRate = sampleRate;
            this.nBits = nBits;
            this.channels = channels;
            Init();
        }

        ~Recorder()
        {
            Close();
        }


        private void Init()
        {
            Console.WriteLine("Recorder  Init");
            //asioOut = new AsioOut();
            //asioOut.InitRecordAndPlayback(null, channels, sampleRate);
            waveIn = new WaveIn
            {
                WaveFormat = new WaveFormat(sampleRate, nBits, channels),
                DeviceNumber = 0
            };
            waveIn.DataAvailable += new EventHandler<WaveInEventArgs>(WaveIn_DataAvailable);
            try
            {
                waveIn.StartRecording();
            }
            catch (NAudio.MmException e)
            {
                
                MessageBox.Show("Mikrofon pole ühendatud (" + e.Message+")", "Mikrofon pole ühendatud");
                //System.Windows.Forms.Application.Exit();
                System.Environment.Exit(32);
            }
        }


        public void Close()
        {
            Console.WriteLine("Recorder close");
            if (isRec)
            {
                StopRec();
                waveIn.StopRecording();
            }

            if (writer != null)
            {
                writer.Close();
            }
            waveIn.Dispose();

        }


        private void WaveIn_DataAvailable(object sender, WaveInEventArgs e)
        {
            if (writer != null)
            {
                writer.Write(e.Buffer, 0, e.BytesRecorded);
            }
        }

        public string StopRec()
        {
            Console.WriteLine("Stop recording");
            isRec = false;
            writer.Flush();
            long lout = writer.Length;
            writer.Close();
            writer = null;
            return LengthToString(lout);
        }

        public void StartRec(string outputFilename)
        {
            Console.WriteLine("Start rec");
            if (isRec)
            {
                StopRec();
            }
            ChkFile(outputFilename);
            isRec = true;
            writer = new WaveFileWriter(outputFilename, waveIn.WaveFormat);

        }

        public string LengthToString(long l)
        {
            long bMin = sampleRate * channels * (nBits / 8);
            long secs = l / bMin;
            long ms = ((l % bMin) * 1000) / bMin;
            return secs + ":" + ms;
        }
        public bool IsRecording()
        {
            return isRec;
        }

        private void ChkFile(string name)
        {
            if (File.Exists(name))
            {
                File.Delete(name);
            }
        }
    }
}
